@@ -4,7 +4,8 @@ import json
 import os
 from collections import OrderedDict
 from . import config
-from .htmlhelpers import *  # noqa
+from .html import *  # noqa
+from .messages import *
 
 
 def addMdnPanels(doc):
