@@ -19,7 +19,7 @@ from . import constants
 from . import datablocks
 from . import markdown
 from .DefaultOrderedDict import DefaultOrderedDict
-from .htmlhelpers import *
+from .html import *
 from .messages import *
 from .repository import *
 
@@ -923,6 +923,7 @@ def getSpecRepository(doc):
         except subprocess.CalledProcessError:
             # check_output will throw CalledProcessError when not in a git repo
             return config.Nil()
+    return config.Nil()
 
 
 def parseDoc(doc):
